Put there all definitions for services that needs to be enabled only on development environment.

Example: 

    On production you install database on bare metal. 
    On development you install database in a container.
    
